@@ -4,8 +4,9 @@ function(lib, pkg)
     if(!require("stats", quietly = TRUE))
 		requite(ts)
     mylib <- dirname(system.file(package = "labstatR"))
-    ver <- packageDescription("labstatR", lib = mylib)["Version"]
-    txt <- c("\n",
+	if(require("utils", quietly=TRUE)){
+     ver <- packageDescription("labstatR", lib = mylib)["Version"]
+     txt <- c("\n",
              paste(sQuote("labstatR"), "version:", ver),
              "\n",
              paste(sQuote("labstatR"),
@@ -19,4 +20,5 @@ function(lib, pkg)
              "\n")
     if(interactive() || getOption("verbose"))
         writeLines(strwrap(txt, indent = 4, exdent = 4))
+	}
 }
